@@ -2,24 +2,27 @@ package SQL::ReservedWords;
 
 use strict;
 use warnings;
-use base 'Exporter';
 use vars '$VERSION';
 
-$VERSION = 0.2;
+$VERSION = 0.3;
 
 use constant SQL92   => 0x01;
 use constant SQL99   => 0x02;
 use constant SQL2003 => 0x04;
 
-use Sub::Exporter -setup => {
-    exports => {
-        is_reserved            => undef,
-        is_reserved_by_sql92   => undef,
-        is_reserved_by_sql99   => undef,
-        is_reserved_by_sql2003 => undef,
-        words                  => undef,
-    }
-};
+{
+    require Sub::Exporter;
+
+    my @exports = qw[
+        is_reserved
+        is_reserved_by_sql92
+        is_reserved_by_sql99
+        is_reserved_by_sql2003
+        words
+    ];
+
+    Sub::Exporter->import( -setup => { exports => \@exports } );
+}
 
 {
     my %WORDS = (
